# 建議改進文檔翻譯 感謝您對本專案的關注！非英文文檔是由大型語言模型自動翻譯的，因此錯誤在所難免。如果您在熟悉的語言中發現問題，我們熱烈歡迎您提出改進建議。 在開始貢獻之前，請花點時間閱讀以下指南，以幫助確保您的建議能夠順利被採納。 # 透過 Weblate 提交建議 我們使用 [Weblate](https://weblate.org/) 來管理我們的文檔翻譯。您可以在 [專案的 Weblate 頁面](https://hosted.weblate.org/projects/pdfmathtranslate-next/) 上查看當前的翻譯狀態並提交建議。 ## 如何提交建議 透過 Weblate 提出翻譯改進建議非常簡單，甚至無需註冊帳戶。請繼續閱讀流程。 假設您想改進 [高級選項 → 高級選項](docs/en/advanced/advanced.md) 中「命令行参数」部分的第一句話： 1. 開啟 [專案的 Weblate 頁面](https://hosted.weblate.org/projects/pdfmathtranslate-next/)。 2. 點擊頂部的 `Search`。 3. 在「Filter」中，輸入您想尋找的文字段落。部分文字內容亦可。 完成後，按下 `Enter`。 4. 按下 `Enter` 後，您將被導向搜尋結果頁面。點選您偏好的結果以開啟編輯視圖。 5. 在編輯視圖中，對翻譯進行更改。完成後，點擊 `建議`。就這樣——您已成功完成一次貢獻。 我們會在您提交建議後進行審核。一旦通過，您的變更將會出現在文件中。

###### Some content on this page has been translated by GPT and may contain errors.